ngff_zarr.ngff_image - ngff-zarr
Description: Module Contents: Classes:,, NgffImage,,,,, Data:,, ComputedCallback,,,,, API:

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Edit this page
Toggle table of contents sidebar

# `ngff_zarr.ngff_image`

## Module Contents

### Classes

`NgffImage` |

### Data

`ComputedCallback` |

### API

ngff_zarr.ngff_image.ComputedCallback

  None

class ngff_zarr.ngff_image.NgffImage
  data: dask.array.core.Array

    None

  dims: Sequence[str]

    None

  scale: Dict[str, float]

    None

  translation: Dict[str, float]

    None

  name: str

    ‘image’

  axes_units: Optional[Mapping[str, ngff_zarr.zarr_metadata.Units]]

    None

  computed_callbacks: List[ngff_zarr.ngff_image.ComputedCallback]

    ‘field(…)’